# Release notes for MUSE v1.3.2 (January 22, 2025)

These are the main changes in MUSE v1.3.2.

## Bug fixes

### Fixed error with the calculation of LCOE ({github}`633`)

- There was an error with the way that LCOE was calculated, which was artificially inflating commodity prices in timeslices with lower levels of production. This is now fixed.

### Fixed incorrect installed year in capacity results ({github}`628`)

- The "installed" column (the year that an asset was installed) was previously incorrect, and has now been fixed.

## Deprecated features

### Dropping the "cvxopt" solver ({github}`622`)
